@@ -3,6 +3,7 @@ from .rest_client import AtlassianRestAPI
 from requests import HTTPError
 import logging
 import os
+import time
 
 log = logging.getLogger(__name__)
 
@@ -701,8 +702,11 @@ class Confluence(AtlassianRestAPI):
         """
         headers = self.form_token_headers
         url = 'spaces/flyingpdf/pdfpageexport.action?pageId={pageId}'.format(pageId=page_id)
-        return self.get(url, headers=headers, not_json_response=True)
+        if self.api_version == 'cloud':
+            url = self.get_pdf_download_url_for_confluence_cloud(url)
 
+        return self.get(url, headers=headers, not_json_response=True)
+        
     def export_page(self, page_id):
         """
         Alias method for export page as pdf
@@ -761,3 +765,47 @@ class Confluence(AtlassianRestAPI):
             response = self.get('rest/supportHealthCheck/1.0/check/')
         return response
 
+    def get_pdf_download_url_for_confluence_cloud(self, url):
+        """
+        Confluence cloud does not return the PDF document when the PDF
+        export is initiated. Instead it starts a process in the background 
+        and provides a link to download the PDF once the process completes.
+        This functions polls the long running task page and returns the
+        download url of the PDF.
+        :param url: URL to initiate PDF export
+        :return: Download url for PDF file
+        """
+        try:
+            long_running_task = True
+            headers = self.form_token_headers
+            log.info('Initiate PDF export from Confluence Cloud')
+            response = self.get(url, headers=headers, not_json_response=True)
+            response_string = response.decode(encoding='utf-8', errors='strict')
+            task_id = response_string.split('name="ajs-taskId" content="')[1].split('">')[0]
+            poll_url = 'runningtaskxml.action?taskId={0}'.format(task_id)
+            while long_running_task:
+                longrunning_task_response = self.get(poll_url, headers=headers, not_json_response=True)
+                longrunning_task_response_parts = longrunning_task_response.decode(encoding='utf-8', errors='strict').split('\n')
+                percentage_complete = longrunning_task_response_parts[6].strip()
+                is_successful = longrunning_task_response_parts[7].strip()
+                is_complete = longrunning_task_response_parts[8].strip()
+                log.info('Sleep for 5s.')
+                time.sleep(5)
+                log.info('Check if export task has completed.')
+                if is_successful == '<isSuccessful>true</isSuccessful>' and is_complete == '<isComplete>true</isComplete>':
+                    log.info(percentage_complete)
+                    log.info('Downloading content...')
+                    log.debug('Extract taskId and download PDF.')
+                    current_status = longrunning_task_response_parts[3]
+                    download_url = current_status.split('href=&quot;/wiki/')[1].split('&quot')[0]
+                    long_running_task = False
+                elif is_successful == '<isSuccessful>false</isSuccessful>' and is_complete == '<isComplete>true</isComplete>':
+                    log.error('PDF conversion not successful.')
+                    return None
+                else:
+                    log.info(percentage_complete)
+        except IndexError as e:
+            log.error(e)
+            return None
+        
+        return download_url
